| Title: | olinkWrapper provides a user-friendly interface for performing quick analysis of Olink data |
|---|---|
| Description: | olinkWrapper provides a user-friendly interface for performing quick analysis of Olink data using the OlinkAnalyze package. It allows for data upload, parameter customization, visualization of results, and exporting of analysis outputs in comprehensive PDF report. |
| Authors: | Jyotirmoy Das [aut, cre] |
| Maintainer: | Jyotirmoy Das <[email protected]> |
| License: | `use_mit_license()`, |
| Version: | 1.3.0 |
| Built: | 2026-05-15 09:41:48 UTC |
| Source: | https://github.com/JD2112/olinkWrapper |
Launch the olinkWrapper Shiny App
run_app()run_app()